pub enum PromptMode {
Ordinary,
Workflow,
}Expand description
Tools and instructions that belong to one submitted user turn.
Workflow mode is explicit and local to the prompt invocation. This keeps one prompt from enabling or disabling workflow tools for another prompt.
Variants