pub struct Settings {Show 33 fields
pub default_provider: Option<String>,
pub default_model: Option<String>,
pub default_thinking_level: Option<String>,
pub transport: Transport,
pub hide_thinking_block: bool,
pub theme: Option<String>,
pub quiet_startup: bool,
pub default_project_trust: ProjectTrustDefault,
pub compaction: CompactionSettings,
pub experimental_context_file: bool,
pub reasoning_effort: ReasoningEffortSettings,
pub retry: RetrySettings,
pub cache_warming: CacheWarmingMode,
pub subagents: SubagentSettings,
pub workflows: WorkflowSettings,
pub steering_mode: QueueMode,
pub follow_up_mode: QueueMode,
pub shell_path: Option<String>,
pub shell_command_prefix: Option<String>,
pub session_dir: Option<String>,
pub enabled_models: Option<Vec<String>>,
pub default_tools: Option<Vec<String>>,
pub external_editor: Option<String>,
pub skills: Vec<String>,
pub prompts: Vec<String>,
pub themes: Vec<String>,
pub enable_skill_commands: Option<bool>,
pub auto_recap: Option<bool>,
pub voice_language: Option<String>,
pub voice_backend: Option<String>,
pub markdown: MarkdownSettings,
pub webmcp: WebMcpSettings,
pub extra: Map<String, Value>,
}Fields
default_provider: Option<String>default_model: Option<String>default_thinking_level: Option<String>transport: Transporthide_thinking_block: booltheme: Option<String>quiet_startup: booldefault_project_trust: ProjectTrustDefaultcompaction: CompactionSettingsexperimental_context_file: boolLet the model edit its live conversation through a private JSON file.
reasoning_effort: ReasoningEffortSettingsretry: RetrySettingscache_warming: CacheWarmingModesubagents: SubagentSettingsworkflows: WorkflowSettingssteering_mode: QueueModefollow_up_mode: QueueModeshell_path: Option<String>shell_command_prefix: Option<String>session_dir: Option<String>enabled_models: Option<Vec<String>>default_tools: Option<Vec<String>>external_editor: Option<String>skills: Vec<String>prompts: Vec<String>themes: Vec<String>enable_skill_commands: Option<bool>auto_recap: Option<bool>None preserves the default-on behavior for existing settings files.
voice_language: Option<String>voice_backend: Option<String>markdown: MarkdownSettingswebmcp: WebMcpSettingsextra: Map<String, Value>Unknown keys survive load/save.
Implementations
Sourceimpl Settings
impl Settings
Sourcepub fn get_or_create_device_id() -> Result<String>
pub fn get_or_create_device_id() -> Result<String>
Read only user settings when creating the installation ID.
pub fn auto_recap_enabled(&self) -> bool
Sourcepub fn load(cwd: &Path, project_trusted: bool) -> Settings
pub fn load(cwd: &Path, project_trusted: bool) -> Settings
Load global settings, overlaying project settings when trusted.
pub fn save_global(&self) -> Result<()>