pub struct RunSnapshot {
pub status: RunStatus,
pub elapsed: Duration,
pub log: Vec<String>,
pub phases: Vec<PhaseSnapshot>,
pub tokens: u64,
pub error: Option<String>,
}Expand description
The whole run as shown in the progress view.
Fields
status: RunStatuselapsed: Durationlog: Vec<String>phases: Vec<PhaseSnapshot>tokens: u64error: Option<String>Implementations
Sourceimpl RunSnapshot
impl RunSnapshot
pub fn total_agents(&self) -> usize
pub fn finished_agents(&self) -> usize
Sourcepub fn active_phase(&self) -> Option<&PhaseSnapshot>
pub fn active_phase(&self) -> Option<&PhaseSnapshot>
The phase with work in flight, or the last one that has any agents.